==> haskell-tasty-hspec-1.2.0.4-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-EL4J9ypBD8WFuW1vA04ihQ
key:                  tasty-hspec-1.2.0.4-EL4J9ypBD8WFuW1vA04ihQ
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  528816878aa3dadefe6e8312ffe289a8
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-EL4J9ypBD8WFuW1vA04ihQ
depends:
    QuickCheck-2.15.0.1-H5XTn9FxFUBGcmB1c3fPtp base-4.17.2.1
    hspec-2.11.1-LYM0tW60Bg1Fw9LJtyOuZx
    hspec-api-2.11.1-LJyJeExZ5kr89Krp0LZvAY
    hspec-core-2.11.1-Aijktg9pPk8GdcQq1nn6u3
    tasty-1.5.2-8MWT7CdCODFHs3Dq0tvOIE
    tasty-quickcheck-0.10.3-2BptsDtY1ln4oZMNcALrAD
    tasty-smallcheck-0.8.2-3HE4zVVUkY795CzFfb75Fl

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hspec-1.2.0.4-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-hspec
version:              1.2.0.4
visibility:           public
id:                   tasty-hspec-1.2.0.4-GIauIhCaKrgE1Q1icBKucc
key:                  tasty-hspec-1.2.0.4-GIauIhCaKrgE1Q1icBKucc
license:              BSD-3-Clause
maintainer:           mitchellwrosen@gmail.com
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/tasty-hspec
synopsis:             Hspec support for the Tasty test framework.
description:
    This package provides a Tasty provider for Hspec test
    suites.

category:             Testing
abi:                  abbfaf6717f10d8c827c10e432c87f03
exposed:              True
exposed-modules:      Test.Tasty.Hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tasty-hspec-1.2.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-hspec
hs-libraries:         HStasty-hspec-1.2.0.4-GIauIhCaKrgE1Q1icBKucc
depends:
    QuickCheck-2.15.0.1-DNiL2W0zGk61NvlUhQ7VCE base-4.17.2.1
    hspec-2.11.2-EAjc0FWNx7lAkrkEnSI1Wl
    hspec-api-2.11.2-4Q8U8Seab9Y7MfdofFAiGw
    hspec-core-2.11.2-JriTHU2KhQ1KyN744wk7HF
    tasty-1.5.2-CkViqWwtJin1eNhDHTt6f
    tasty-quickcheck-0.10.3-9q4hEYy6k26176gVqfzwkP
    tasty-smallcheck-0.8.2-249s9vsT9yCLLUfujb23nr

haddock-interfaces:   /usr/share/doc/haskell-tasty-hspec/html/tasty-hspec.haddock
haddock-html:         /usr/share/doc/haskell-tasty-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
